==> igniteui-react-16.16.2.tgz: package/esm2015/lib/MaskInput.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { InputBase } from "./InputBase";
import { MaskInputDir_$type } from "./MaskInputDir";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { MaskInputValueMode_$type } from "./MaskInputValueMode";
/**
 * @hidden
 */
export let MaskInput = /*@__PURE__*/ (() => {
    class MaskInput extends InputBase {
        get y() {
            let ret_ = this.f.c("dir");
            ret_ = enumGetBox(MaskInputDir_$type, EnumUtil.getEnumValue(MaskInputDir_$type, EnumUtil.parse(MaskInputDir_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(MaskInputDir_$type, ret_);
        }
        set y(a) {
            let value_ = enumGetBox(MaskInputDir_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.f.i("dir", value_);
        }
        get aa() {
            let ret_ = this.f.c("invalid");
            return ret_;
        }
        set aa(a) {
            let value_ = a;
            this.f.i("invalid", value_);
        }
        get z() {
            let ret_ = this.f.c("valueMode");
            ret_ = enumGetBox(MaskInputValueMode_$type, EnumUtil.getEnumValue(MaskInputValueMode_$type, EnumUtil.parse(MaskInputValueMode_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(MaskInputValueMode_$type, ret_);
        }
        set z(a) {
            let value_ = enumGetBox(MaskInputValueMode_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.f.i("valueMode", value_);
        }
        get ad() {
            let ret_ = this.f.c("value");
            return ret_;
        }
        set ad(a) {
            let value_ = a;
            this.f.i("value", value_);
        }
        get ab() {
            let ret_ = this.f.c("mask");
            return ret_;
        }
        set ab(a) {
            let value_ = a;
            this.f.i("mask", value_);
        }
        get ac() {
            let ret_ = this.f.c("prompt");
            return ret_;
        }
        set ac(a) {
            let value_ = a;
            this.f.i("prompt", value_);
        }
        af() {
            this.nativeElement.connectedCallback();
        }
        ag() {
            this.nativeElement.reportValidity();
        }
        ai(a) {
            this.nativeElement.setCustomValidity(a);
        }
        ae() {
            this.nativeElement.checkValidity();
        }
        ah() {
            this.nativeElement.select();
        }
    }
    MaskInput.$t = /*@__PURE__*/ markType(MaskInput, 'MaskInput', InputBase.$);
    return MaskInput;
})();

==> igniteui-react-18.5.1.tgz: package/esm2015/lib/MaskInput.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { MaskInputBase } from "./MaskInputBase";
import { MaskInputValueMode_$type } from "./MaskInputValueMode";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
/**
 * @hidden
 */
export let MaskInput = /*@__PURE__*/ (() => {
    class MaskInput extends MaskInputBase {
        get ae() {
            let ret_ = this.f.n("valueMode");
            ret_ = enumGetBox(MaskInputValueMode_$type, EnumUtil.getEnumValue(MaskInputValueMode_$type, this.f.f(MaskInputValueMode_$type, ret_)));
            return EnumUtil.getEnumValue(MaskInputValueMode_$type, ret_);
        }
        set ae(a) {
            let value_ = enumGetBox(MaskInputValueMode_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.f.v("valueMode", value_);
        }
        get ag() {
            let ret_ = this.f.n("value");
            return ret_;
        }
        set ag(a) {
            let value_ = a;
            this.f.v("value", value_);
        }
        get af() {
            let ret_ = this.f.n("mask");
            return ret_;
        }
        set af(a) {
            let value_ = a;
            this.f.v("mask", value_);
        }
        ai() {
            this.nativeElement.reportValidity();
        }
        ah() {
            this.nativeElement.checkValidity();
        }
    }
    MaskInput.$t = /*@__PURE__*/ markType(MaskInput, 'MaskInput', MaskInputBase.$);
    return MaskInput;
})();
